@@ -48,6 +48,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 	isNew = istemplate > 0 || _target == NULL;
 	typeChanged = false;
+	fieldsChanged = false;
 
 	this->target = _target;
 	this->parent = paTarget;
@@ -226,7 +227,13 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 		componentLayout->addWidget(typeLineEdit, 3, 3, 1, 4);
 	}
 	else {
-
+		elType = -1;
+		for(int i = 0; i < this->parent->types->size(); i++) {
+			if (this->target->type == this->parent->types->at(i)) {
+				elType = i;
+				break;
+			}
+		}
 	}
 
 	vboxlayout->addLayout(componentLayout);
@@ -331,6 +338,8 @@ void DetailWindow::modifyFields() {
 		createFieldDlg->setMinimumSize(size().width(),size().height()-100);
 		createFieldDlg->exec();
 
+
+
 		////qDebug () << "NOW ";
 
 		showFields ();
@@ -460,7 +469,31 @@ void DetailWindow::showFields () {
 			}
 			else {
 				if (field->value.length() > 0) {
-					QLabel * nameLabel = new QLabelW(field->name, true, this);
+					QLabel * nameLabel;
+
+					if (QLocale::system().name() != "en") {
+						if (elType >= 0) {
+							int i = 0;
+							for (; i < parent->fieldsByType->at (elType)->size(); i++) {
+								TargetField tmp = parent->fieldsByType->at (elType)->at(i);
+								if (tmp.originalName == field->name) {
+									nameLabel = new QLabelW(tmp.name, true, this);
+									i = -1;
+									break;
+								}
+							}
+							if (i != -1) {
+								nameLabel = new QLabelW(field->name, true, this);
+							}
+						}
+						else {
+							nameLabel = new QLabelW(field->name, true, this);
+						}
+					}
+					else {
+						nameLabel = new QLabelW(field->name, true, this);
+					}
+
 					nameLabel->setFont (QFont("arial", 11, 1, true));
 					nameLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 					nameLabel->setContentsMargins(0, 0, 10, 0);
@@ -544,14 +577,13 @@ void DetailWindow::changeFields (int a) {
 	for (int i = 0; i < parent->fieldsByType->at (a)->size(); i++) {
 		TargetField tmp = parent->fieldsByType->at (a)->at(i);
 
-		if (!target->existField (tmp.name)) {
+		if (!target->existField (tmp.name) && !target->existField (tmp.originalName)) {
 			TargetField * f;
 
 			f = new TargetField (tmp.name, tmp.type, tmp.encrypted, tmp.order);
 
 			target->fields.append(f);
 		}
-
 	}
 }
 
@@ -944,7 +976,7 @@ void DetailWindow::closeEvent(QCloseEvent *event) {
 	if ((!forceClose) && (edit || isNew)) {
 		bool isModified = false;
 
-		isModified |= typeChanged || nameLineEdit->isModified() || groupLineEdit->isModified();
+		isModified |= fieldsChanged || typeChanged || nameLineEdit->isModified() || groupLineEdit->isModified();
 
 		for (int i = 0; (!isModified) && (i < target->fields.count()); i++) {
 			TargetField * field = target->fields[i];
@@ -985,6 +1017,13 @@ CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 	pos = 0;
 	this->target = target;
 	this->parent = paTarget;
+	_fieldsChanged = false;
+
+	// COPY FIELDS
+	for (int i = 0; i < this->target->fields.size(); i++) {
+		TargetField * item = new TargetField(this->target->fields.at(i));
+		fields.append(item);
+	}
 
 	setContextMenuPolicy(Qt::NoContextMenu);
 
@@ -1105,12 +1144,12 @@ CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 }
 
 void CreateFieldDialog::update () {
-	if (pos < target->fields.length()) {
+	if (pos < fields.length()) {
 		int type = typeLineEdit->itemData(typeLineEdit->currentIndex()).toInt();
 		int order = QVariant (orderEdit->text()).toInt();
-		target->fields[pos]->name = nameLineEdit->text();
-		target->fields[pos]->type = type;
-		target->fields[pos]->order = order;
+		fields[pos]->name = nameLineEdit->text();
+		fields[pos]->type = type;
+		fields[pos]->order = order;
 	}
 }
 
@@ -1122,24 +1161,28 @@ void CreateFieldDialog::previous () {
 	}
 }
 void CreateFieldDialog::addNew () {
+	_fieldsChanged = true;
+
 	update ();
-	pos = target->fields.length();
-	target->fields.append(new TargetField ("", TYPE_STRING, true, 100));
+	pos = fields.length();
+	fields.append(new TargetField ("", TYPE_STRING, true, 100));
 
 	showField ();
 }
 void CreateFieldDialog::next () {
-	if ((pos + 1) < target->fields.length()) {
+	if ((pos + 1) < fields.length()) {
 		update ();
 		pos++;
 		showField ();
 	}
 }
 void CreateFieldDialog::deleteCurrent () {
-	if (pos >= 0 && pos < target->fields.length()) {
+	if (pos >= 0 && pos < fields.length()) {
+		_fieldsChanged = true;
+
 		update ();
-		target->fields.removeAt(pos);
-		if (pos >= target->fields.length()) {
+		fields.removeAt(pos);
+		if (pos >= fields.length()) {
 			pos--;
 			if (pos < 0) pos = 0;
 		}
@@ -1151,8 +1194,9 @@ void CreateFieldDialog::deleteCurrent () {
 		orderEdit->hide ();
 	}
 }
+
 void CreateFieldDialog::showField () {
-	if (pos < target->fields.length()) {
+	if (pos < fields.length()) {
 		if (!nameLineEdit->isEnabled()) {
 			nameLineEdit->setDisabled(false);
 			typeLineEdit->setDisabled(false);
@@ -1176,29 +1220,54 @@ void CreateFieldDialog::showField () {
 	else {
 		previousButton->setDisabled(false);
 	}
-	if ((pos + 1) >= target->fields.length()) {
+	if ((pos + 1) >= fields.length()) {
 		nextButton->setDisabled(true);
 	}
 	else {
 		nextButton->setDisabled(false);
 	}
-	if (pos >= 0 && pos < target->fields.length()) {
+	if (pos >= 0 && pos < fields.length()) {
 		deleteButton->setDisabled(false);
 	}
 	else {
 		deleteButton->setDisabled(true);
 	}
-	if (pos < target->fields.length()) {
-		nameLineEdit->setText(target->fields[pos]->name);
-		int i = typeLineEdit->findData(QVariant (target->fields[pos]->type));
+	if (pos < fields.length()) {
+		nameLineEdit->setText(fields[pos]->name);
+		int i = typeLineEdit->findData(QVariant (fields[pos]->type));
 		typeLineEdit->setCurrentIndex(i);
-		orderEdit->setText(QString::number(target->fields[pos]->order));
+		orderEdit->setText(QString::number(fields[pos]->order));
 	}
 }
+
 void CreateFieldDialog::save () {
 	update ();
+
+	if (_fieldsChanged) {
+		// REMOVE PREVIOUS
+		for (int i = 0; i < this->target->fields.size(); i++) {
+			TargetField * item = this->target->fields.at(i);
+			delete item;
+		}
+		this->target->fields.clear();
+
+		// RECOVER FIELDS
+		for (int i = 0; i < fields.size(); i++) {
+			TargetField * item = new TargetField(fields.at(i));
+			this->target->fields.append(item);
+		}
+
+		parent->fieldsChanged = _fieldsChanged;
+	}
+
 	close();
 }
-CreateFieldDialog::~CreateFieldDialog() {
 
+CreateFieldDialog::~CreateFieldDialog() {
+	for (int i = 0; i < fields.size(); i++) {
+		TargetField * item = fields.at(i);
+		delete item;
+	}
+
+	fields.clear();
 }
