@@ -13,15 +13,23 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
+    QString lang;
+    if (argc > 1) {
+    	qDebug () << "setting lang to " << argv [1];
+    	lang = argv[1];
+    }
+    else
+    	lang = QLocale::system().name();
+
     QTranslator qtTranslator;
-    qtTranslator.load(QString("qt_") + QLocale::system().name(),
+    qtTranslator.load(QString("qt_") + lang,
             QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     app.installTranslator(&qtTranslator);
 
     //qDebug () << "LANGUAGE " << QLocale::system().name();
 
     QTranslator myappTranslator;
-    myappTranslator.load(QString (":/resources/locale/qtwallet_") + QLocale::system().name());
+    myappTranslator.load(QString (":/resources/locale/qtwallet_") + lang);
     app.installTranslator(&myappTranslator);
 
 	eWallet * w = new eWallet();
